aic_processor_context_destroy

Function aic_processor_context_destroy 

pub unsafe extern "C" fn aic_processor_context_destroy(
    context: *mut AicProcessorContext,
)
Releases a processor context handle.

After calling this function, the context handle becomes invalid. This function is safe to call with NULL. Destroying the context does not destroy the associated processor.

Parameters

  • context: Context instance to destroy. Can be NULL.

Safety

  • Thread-safe: Can be called from any thread.
  • The context pointer must have been created by aic_processor_context_create when non-NULL.