aic_processor_destroy

Function aic_processor_destroy 

pub unsafe extern "C" fn aic_processor_destroy(
    processor: *mut AicProcessor,
)
Releases all resources associated with a processor instance.

After calling this function, the processor handle becomes invalid. This function is safe to call with NULL.

Parameters

  • processor: Processor instance to destroy. Can be NULL.

Safety

  • This function is not thread-safe. Ensure no other threads are using the processor during initialization.
  • The processor pointer must have been created by aic_processor_create when non-NULL.