pub unsafe extern "C" fn aic_processor_context_destroy(
context: *mut AicProcessorContext,
)Expand description
Releases a processor context handle.
After calling this function, the context handle becomes invalid. This function is safe to call with NULL. Destroying the context does not destroy the associated processor.
Parameters
context: Context instance to destroy. Can be NULL.
Safety
- Thread-safe: Can be called from any thread.
- The
contextpointer must have been created byaic_processor_context_createwhen non-NULL.